

TODO_25_46_48_20: provide non-mock-able test config.

At the moment, FS_14_59_14_06 pending requests spinner has to be disabled as End2End test cannot handle its output.

Config is not possible to be mocked in some test modes (see FS_66_17_43_42 test infra) where testee
is out of the process running current test. However, to test certain features default config files are not adequate.

There could be few ways:
*   Generate config (or keep static) and override conf location via FS_47_63_35_61 env vars.
*   Overwrite default config and restore it after the test (a bit messy).
